# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, unicode_literals

import sys
import time

bust = {'bust': time.time()}

CONFIGURABLE_OPTIONS = ['--db', '--cms-version', '--django-version', '--i18n',
                        '--reversion', '--languages', '--timezone', '--use-tz',
                        '--permissions', '--bootstrap', '--templates',
                        '--starting-page']

DJANGOCMS_DEVELOP = 'https://github.com/yakky/django-cms/archive/develop.zip?{bust}'.format(
    **bust
)
DJANGOCMS_RC = 'https://github.com/divio/django-cms/archive/release/3.7.x.zip?{bust}'.format(
    **bust
)
DJANGOCMS_BETA = DJANGOCMS_RC
DJANGOCMS_36 = 'django-cms>=3.6,<3.7'

if sys.version_info > (3, 0):
    DJANGOCMS_37 = 'django-cms>=3.7,<3.8'
else:
    DJANGOCMS_37 = 'django-cms>=3.7,<3.7.2'

if sys.version_info >= (3, 5):
    DJANGOCMS_SUPPORTED = ('3.6', '3.7', 'stable', 'lts', 'develop', 'rc')
    DJANGOCMS_STABLE = '3.7'
    DJANGOCMS_LTS = '3.7'
else:
    DJANGOCMS_SUPPORTED = ('3.6', '3.7', 'stable', 'lts', 'develop', 'rc')
    DJANGOCMS_STABLE = '3.7'
    DJANGOCMS_LTS = '3.7'
DJANGOCMS_DEFAULT = DJANGOCMS_STABLE

DJANGO_DEVELOP = 'https://github.com/django/django/archive/master.zip?{bust}'.format(**bust)
DJANGO_BETA = 'https://github.com/django/django/archive/master.zip?{bust}'.format(**bust)
if sys.version_info >= (3, 6):
    DJANGO_SUPPORTED = ('1.11', '2.0', '2.1', '2.2', '3.0', 'stable', 'lts')
    DJANGO_STABLE = '3.0'
    DJANGO_LTS = '2.2'
elif (3, 6) > sys.version_info >= (3, 5):
    DJANGO_SUPPORTED = ('1.11', '2.0', '2.1', '2.2', 'stable', 'lts')
    DJANGO_STABLE = '2.2'
    DJANGO_LTS = '2.2'
else:
    DJANGO_SUPPORTED = ('1.11', 'stable', 'lts')
    DJANGO_STABLE = '1.11'
    DJANGO_LTS = '1.11'
DJANGO_DEFAULT = DJANGO_STABLE

CMS_VERSION_MATRIX = {
    'stable': DJANGOCMS_STABLE,
    'lts': DJANGOCMS_LTS,
    'rc': DJANGOCMS_RC,
    'beta': DJANGOCMS_BETA,
    'develop': DJANGOCMS_DEVELOP,
}
DJANGO_VERSION_MATRIX = {
    'stable': DJANGO_STABLE,
    'lts': DJANGO_LTS,
    'rc': DJANGO_STABLE,
    'beta': DJANGO_STABLE,
    'develop': DJANGO_STABLE
}
VERSION_MATRIX = {
    '3.6': ('1.11', '2.1'),
    '3.7': ('1.11', '3.0'),
    DJANGOCMS_BETA: ('1.11', '3.0'),
    DJANGOCMS_RC: ('1.11', '3.0'),
    DJANGOCMS_DEVELOP: ('1.11', '2.2', '3.0'),
}
PACKAGE_MATRIX = {
    '3.6': DJANGOCMS_36,
    '3.7': DJANGOCMS_37,
    DJANGOCMS_RC: DJANGOCMS_RC,
    DJANGOCMS_BETA: DJANGOCMS_BETA,
    DJANGOCMS_DEVELOP: DJANGOCMS_DEVELOP,
}

REQUIREMENTS = {
    'default': [
        'html5lib>=1.0.1',
        'Pillow>=3.0',
        'six',
        'pytz',
    ],
    'django-1.11': [
        'django-classy-tags>=0.9',
        'django-sekizai>=1.0',
        'django-mptt>0.9',
        'django-formtools>=2.1,<2.2',
    ],
    'django-2.0': [
        'django-classy-tags>=0.9',
        'django-sekizai>=1.0',
        'django-mptt>0.9',
    ],
    'django-2.1': [
        'django-classy-tags>=0.9',
        'django-sekizai>=1.0',
        'django-mptt>0.9',
    ],
    'django-2.2': [
        'django-classy-tags>=0.9',
        'django-sekizai>=1.0',
        'django-mptt>0.9',
    ],
    'django-3.0': [
        'django-classy-tags>=0.9',
        'django-sekizai>=1.0',
        'django-mptt>0.9',
    ],
    'reversion-django-1.11': [
        'django-reversion>=2.0,<2.1',
    ],
    'cms-3.6': [
        'djangocms-admin-style>=1.4,<1.5',
        'django-treebeard>=4.0,<5.0',
    ],
    'cms-3.7': [
        'djangocms-admin-style>=1.4,<1.5',
        'django-treebeard>=4.0,<5.0',
    ],
    'cms-master': [
        'https://github.com/divio/djangocms-admin-style/archive/master.zip?{bust}'.format(**bust),
        'django-treebeard>=4.0,<5.0',
    ],
    'plugins-3.6': [
        'djangocms-text-ckeditor>=3.7,<4.0',
        'djangocms-link>=2.5,<2.7',
        'djangocms-icon>=1.4,<1.6',
        'djangocms-style>=2.2,<2.4',
        'djangocms-googlemap>=1.3,<1.5',
        'djangocms-snippet>=2.2,<2.4',
        'djangocms-video>=2.1,<2.4',
        'djangocms-file>=2.3,<2.5',
        'djangocms-picture>=2.3,<2.5',
        'djangocms-bootstrap4>=1.5,<1.7',
    ],
    'plugins-3.7': [
        'djangocms-text-ckeditor>=3.7,<4.0',
        'djangocms-link>=2.5,<2.7',
        'djangocms-icon>=1.4,<1.6',
        'djangocms-style>=2.2,<2.4',
        'djangocms-googlemap>=1.3,<1.5',
        'djangocms-snippet>=2.2,<2.4',
        'djangocms-video>=2.1,<2.4',
        'djangocms-file>=2.3,<2.5',
        'djangocms-picture>=2.3,<2.5',
        'djangocms-bootstrap4>=1.5,<1.7',
    ],
    'plugins-master': [
        'https://github.com/divio/djangocms-text-ckeditor/archive/master.zip?{bust}'
        ''.format(**bust),
        'https://github.com/divio/djangocms-file/archive/master.zip?{bust}'.format(**bust),
        'https://github.com/divio/djangocms-link/archive/master.zip?{bust}'.format(**bust),
        'https://github.com/divio/djangocms-icon/archive/master.zip?{bust}'.format(**bust),
        'https://github.com/divio/djangocms-style/archive/master.zip?{bust}'.format(**bust),
        'https://github.com/divio/djangocms-googlemap/archive/master.zip?{bust}'.format(**bust),
        'https://github.com/divio/djangocms-snippet/archive/master.zip?{bust}'.format(**bust),
        'https://github.com/divio/djangocms-picture/archive/master.zip?{bust}'.format(**bust),
        'https://github.com/divio/djangocms-video/archive/master.zip?{bust}'.format(**bust),
        'https://github.com/divio/djangocms-bootstrap4/archive/master.zip?{bust}'.format(**bust),
    ],
    'plugins-basic': [
    ],
    'plugins-basic-master': [
    ],
    'filer': [
        'easy_thumbnails',
        'django-filer>=1.3',
    ],
}

TEMPLATES_1_8 = """
TEMPLATES = [
    {{
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [{dirs}],
        'OPTIONS': {{
            'context_processors': [
                {processors}
            ],
            'loaders': [
                {loaders}
            ],
        }},
    }},
]
"""

PLUGIN_LIST_TEXT = """
djangocms installer will install and configure the following plugins:
 * djangocms-text-ckeditor (Text plugin)
 * djangocms-link (Link plugin)
 * djangocms-file (File plugin)
 * djangocms-picture (Image plugin)
 * djangocms-style (Style plugin)
 * djangocms-snippet (Snippet plugin)
 * djangocms-googlemap (GoogleMap plugin)
 * djangocms-video (Video plugin)
"""

DRIVERS = {
    'django.db.backends.postgresql': 'psycopg2',
    'django.db.backends.postgresql_psycopg2': 'psycopg2',
    'django.contrib.gis.db.backends.postgis': 'postgis',
    'django.db.backends.postgresql_postgis': 'postgis',
    'django.db.backends.mysql': 'mysqlclient',
    'django.db.backends.sqlite3': '',
}

DEFAULT_PROJECT_HEADER = """# -*- coding: utf-8 -*-
import os  # isort:skip
gettext = lambda s: s
"""
STATICFILES_DEFAULT = """STATICFILES_DIRS = (
    # Put strings here, like "/home/html/static" or "C:/www/django/static".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
)"""

BASE_DIR = """
BASE_DIR = os.path.dirname(os.path.dirname(__file__))
"""

VERSION_WARNING = '{0} version of {1} is not supported and it may not work as expected'



# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, unicode_literals

from django.contrib.auth import get_user_model

if __name__ == '__main__':
    import django

    django.setup()

    User = get_user_model()
    if not User.objects.filter(is_superuser=True).exists():
        User.objects.create_superuser('admin', 'admin@admin.com', 'admin')



# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, unicode_literals

import sys

from .main import execute

if __name__ == '__main__':
    status = execute()
    if status:
        sys.exit(status)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys

from setuptools import find_packages, setup

import djangocms_installer

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

requirements = open('requirements.txt').readlines()
test_requirements = []


setup(
    name='djangocms-installer',
    version=djangocms_installer.__version__,
    description='Command to easily bootstrap django CMS projects',
    long_description=readme + '\n\n' + history,
    author='Iacopo Spalletti',
    author_email='i.spalletti@nephila.it',
    url='https://github.com/nephila/djangocms-installer',
    packages=find_packages(),
    package_dir={'djangocms_installer': 'djangocms_installer'},
    include_package_data=True,
    install_requires=requirements,
    entry_points={
        'console_scripts': [
            'djangocms = djangocms_installer.main:execute',
        ]
    },
    license='BSD',
    zip_safe=False,
    keywords='djangocms-installer',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
        'Framework :: Django :: 2.1',
        'Framework :: Django :: 2.2',
        'Topic :: Software Development',
    ],
    test_suite='tests',
    tests_require=test_requirements
)



# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, unicode_literals

import logging
import os.path
import shutil
import subprocess
import sys

from djangocms_installer.utils import query_yes_no

logger = logging.getLogger('')


def check_install(config_data):
    """
    Here we do some **really** basic environment sanity checks.

    Basically we test for the more delicate and failing-prone dependencies:
     * database driver
     * Pillow image format support

    Many other errors will go undetected
    """
    errors = []

    # PIL tests
    try:
        from PIL import Image

        try:
            im = Image.open(os.path.join(os.path.dirname(__file__), '../share/test_image.png'))
            im.load()
        except IOError:  # pragma: no cover
            errors.append(
                'Pillow is not compiled with PNG support, see "Libraries installation issues" '
                'documentation section: https://djangocms-installer.readthedocs.io/en/latest/'
                'libraries.html.'
            )
        try:
            im = Image.open(os.path.join(os.path.dirname(__file__), '../share/test_image.jpg'))
            im.load()
        except IOError:  # pragma: no cover
            errors.append(
                'Pillow is not compiled with JPEG support, see "Libraries installation issues" '
                'documentation section: https://djangocms-installer.readthedocs.io/en/latest/'
                'libraries.html'
            )
    except ImportError:  # pragma: no cover
        errors.append(
            'Pillow is not installed check for installation errors and see "Libraries installation'
            ' issues" documentation section: https://djangocms-installer.readthedocs.io/en/latest/'
            'libraries.html'
        )

    # PostgreSQL test
    if config_data.db_driver == 'psycopg2' and not config_data.no_db_driver:  # pragma: no cover
        try:
            import psycopg2  # NOQA
        except ImportError:
            errors.append(
                'PostgreSQL driver is not installed, but you configured a PostgreSQL database, '
                'please check your installation and see "Libraries installation issues" '
                'documentation section: https://djangocms-installer.readthedocs.io/en/latest/'
                'libraries.html'
            )

    # MySQL test
    if config_data.db_driver == 'mysqlclient' and not config_data.no_db_driver:  # pragma: no cover  # NOQA
        try:
            import MySQLdb  # NOQA
        except ImportError:
            errors.append(
                'MySQL driver is not installed, but you configured a MySQL database, please check '
                'your installation and see "Libraries installation issues" documentation section: '
                'https://djangocms-installer.readthedocs.io/en/latest/libraries.html'
            )
    if errors:  # pragma: no cover
        raise EnvironmentError('\n'.join(errors))


def requirements(req_file, pip_options='', is_file=False, verbose=False):
    args = ['install', '--disable-pip-version-check']
    if not verbose:
        args.append('-q')
    if pip_options:
        args.extend([opt for opt in pip_options.split(' ') if opt])
    if is_file:  # pragma: no cover
        args += ['-r', req_file]
    else:
        args.extend(['{0}'.format(package) for package in req_file.split()])
    cmd = [sys.executable, '-mpip'] + args
    if verbose:
        sys.stdout.write('python path: {0}\n'.format(sys.executable))
        sys.stdout.write('packages install command: {0}\n'.format(' '.join(cmd)))
    try:
        subprocess.check_output(['python', '-msite'], stderr=subprocess.STDOUT)
        output = subprocess.check_output(cmd, stderr=subprocess.STDOUT)
        sys.stdout.write(output.decode('utf-8'))
    except Exception as e:
        logger.error('cmd : %s :%s' % (e.cmd, e.output))
        raise

    return True


def write_requirements(config_data):
    with open(os.path.join(config_data.project_directory, 'requirements.txt'), 'w') as reqfile:
        reqfile.write(config_data.requirements)


def cleanup(requirements):  # pragma: no cover
    import pip

    args = ['uninstall', '-q', '-y']
    args.extend(requirements.split())
    pip.main(args)
    return True


def cleanup_directory(config_data):
    """
    Asks user for removal of project directory and eventually removes it
    """
    if os.path.exists(config_data.project_directory):
        choice = False
        if config_data.noinput is False and not config_data.verbose:
            choice = query_yes_no(
                'The installation failed.\n'
                'Do you want to clean up by removing {0}?\n'
                '\tWarning: this will delete all files in:\n'
                '\t\t{0}\n'
                'Do you want to cleanup?'.format(
                    os.path.abspath(config_data.project_directory)
                ),
                'no'
            )
        else:
            sys.stdout.write('The installation has failed.\n')
        if config_data.skip_project_dir_check is False and (choice or
                                                            (config_data.noinput and
                                                             config_data.delete_project_dir)):
            sys.stdout.write('Removing everything under {0}\n'.format(
                os.path.abspath(config_data.project_directory)
            ))
            shutil.rmtree(config_data.project_directory, True)



# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function, unicode_literals

import json


def create_pages():
    from cms.models import Placeholder
    from cms.api import create_page, add_plugin, publish_page
    from django.conf import settings
    from django.contrib.auth.models import User
    from django.utils.translation import ugettext_lazy as _

    placeholder = {}

    with open('starting_page.json') as data_file:
        content = json.load(data_file)

    try:
        # try to get a feature template with fallback
        template = settings.CMS_TEMPLATES[1][0]
        if template != 'feature.html':
            template = settings.CMS_TEMPLATES[0][0]
    except IndexError:
        template = settings.CMS_TEMPLATES[0][0]

    lang = settings.LANGUAGES[0][0]
    page = create_page(_('Home'), template, lang)
    placeholder['main'] = page.placeholders.get(slot='content')

    try:
        # try to get a feature placeholder
        placeholder_feature = page.placeholders.get(slot='feature')
        add_plugin(placeholder_feature, 'TextPlugin', lang, body=content['feature'])
    except Placeholder.DoesNotExist:
        # fallback, add it to the
        add_plugin(placeholder['main'], 'TextPlugin', lang, body=content['feature'])

    # Add main content to a Bootstrap4GridRow
    row_plugin = add_plugin(placeholder['main'], 'Bootstrap4GridRowPlugin', lang)
    for column_content in content['main']:
        col = add_plugin(
            placeholder['main'], 'Bootstrap4GridColumnPlugin', lang, target=row_plugin
        )
        add_plugin(placeholder['main'], 'TextPlugin', lang, body=column_content, target=col)

    # In order to publish the page there needs to be at least one user
    if User.objects.count() > 0:
        publish_page(page, User.objects.all()[0], lang)


if __name__ == '__main__':
    import django

    django.setup()
    create_pages()
